@@ -29,11 +29,12 @@ import os
 import re
 from collections import OrderedDict, defaultdict
 from datetime import date
-from typing import Callable, Dict, Iterable, List, Optional
+from typing import Callable, Dict, Iterable, List, Optional, Tuple
 
 from jinja2 import Environment, PackageLoader
 
 from commitizen import defaults
+from commitizen.bump import normalize_tag
 from commitizen.exceptions import InvalidConfigurationError
 from commitizen.git import GitCommit, GitTag
 
@@ -281,3 +282,71 @@ def incremental_build(new_content: str, lines: List, metadata: Dict) -> List:
     if not isinstance(latest_version_position, int):
         output_lines.append(new_content)
     return output_lines
+
+
+def get_smart_tag_range(
+    tags: List[GitTag], newest: str, oldest: Optional[str] = None
+) -> List[GitTag]:
+    """Smart because it finds the N+1 tag.
+
+    This is because we need to find until the next tag
+    """
+    accumulator = []
+    keep = False
+    if not oldest:
+        oldest = newest
+    for index, tag in enumerate(tags):
+        if tag.name == newest:
+            keep = True
+        if keep:
+            accumulator.append(tag)
+        if tag.name == oldest:
+            keep = False
+            try:
+                accumulator.append(tags[index + 1])
+            except IndexError:
+                pass
+            break
+    return accumulator
+
+
+def get_oldest_and_newest_rev(
+    tags: List[GitTag], version: str, tag_format: str
+) -> Tuple[Optional[str], Optional[str]]:
+    """Find the tags for the given version.
+
+    `version` may come in different formats:
+    - `0.1.0..0.4.0`: as a range
+    - `0.3.0`: as a single version
+    """
+    oldest: Optional[str] = None
+    newest: Optional[str] = None
+    try:
+        oldest, newest = version.split("..")
+    except ValueError:
+        newest = version
+
+    newest_tag = normalize_tag(newest, tag_format=tag_format)
+
+    oldest_tag = None
+    if oldest:
+        oldest_tag = normalize_tag(oldest, tag_format=tag_format)
+
+    tags_range = get_smart_tag_range(tags, newest=newest_tag, oldest=oldest_tag)
+    if not tags_range:
+        return None, None
+
+    oldest_rev: Optional[str] = tags_range[-1].name
+    newest_rev = newest_tag
+
+    # check if it's the first tag created
+    # and it's also being requested as part of the range
+    if oldest_rev == tags[-1].name and oldest_rev == oldest_tag:
+        return None, newest_rev
+
+    # when they are the same, and it's also the
+    # first tag created
+    if oldest_rev == newest_rev:
+        return None, newest_rev
+
+    return oldest_rev, newest_rev
